@@ -1,6 +1,6 @@
 import numpy as np
 
-from popsynth.distribution import LuminosityDistribution, DistributionParameter
+from popsynth.distribution import DistributionParameter, LuminosityDistribution
 
 
 class LogNormalDistribution(LuminosityDistribution):
@@ -34,8 +34,9 @@ class LogNormalDistribution(LuminosityDistribution):
 
     def phi(self, L):
 
-        return (1.0 / (self.tau * L * np.sqrt(2 * np.pi))) * np.exp(-(
-            (np.log(L) - self.mu)**2) / (2 * self.tau**2))
+        return (1.0 / (self.tau * L * np.sqrt(2 * np.pi))) * np.exp(
+            -((np.log(L) - self.mu) ** 2) / (2 * self.tau ** 2)
+        )
 
     def draw_luminosity(self, size=1):
 
