@@ -1,6 +1,6 @@
 import numpy as np
 
-from popsynth.distribution import LuminosityDistribution, DistributionParameter
+from popsynth.distribution import DistributionParameter, LuminosityDistribution
 
 
 class ParetoDistribution(LuminosityDistribution):
@@ -26,9 +26,9 @@ class ParetoDistribution(LuminosityDistribution):
         """
         lf_form = r"\frac{\alpha L_{\rm min}^{\alpha}}{L^{\alpha+1}}"
 
-        super(ParetoDistribution, self).__init__(seed=seed,
-                                                 name=name,
-                                                 form=lf_form)
+        super(ParetoDistribution, self).__init__(
+            seed=seed, name=name, form=lf_form
+        )
 
     def phi(self, L):
 
@@ -36,8 +36,9 @@ class ParetoDistribution(LuminosityDistribution):
 
         idx = L >= self.Lmin
 
-        out[idx] = self.alpha * self.Lmin**self.alpha / L[idx]**(self.alpha +
-                                                                 1)
+        out[idx] = (
+            self.alpha * self.Lmin ** self.alpha / L[idx] ** (self.alpha + 1)
+        )
 
         return out
 
