@@ -25,8 +25,7 @@ from popsynth.utils.spherical_geometry import xyz
 log = setup_logger(__name__)
 
 wine = "#8F2727"
-dark, dark_highlight, mid, mid_highlight, light, light_highlight = betagen(
-    wine)
+dark, dark_highlight, mid, mid_highlight, light, light_highlight = betagen(wine)
 
 
 class Population(object):
@@ -120,7 +119,8 @@ class Population(object):
         self._phi = phi  # type: ArrayLike
 
         assert len(known_distances) + len(unknown_distance_idx) == sum(
-            selection), "the distances are not the correct size"
+            selection
+        ), "the distances are not the correct size"
 
         # latent fluxes
         self._fluxes = fluxes  # type: ArrayLike
@@ -156,7 +156,9 @@ class Population(object):
 
         self._n_objects = len(selection)  # type: int
         self._n_detections = sum(self._selection)  # type: int
-        self._n_non_detections = self._n_objects - self._n_detections  # type: int
+        self._n_non_detections = (
+            self._n_objects - self._n_detections
+        )  # type: int
 
         self._pop_synth: Optional[Dict[str, Any]] = pop_synth
 
@@ -191,7 +193,7 @@ class Population(object):
         """
         The networkx graph of the population
 
-        :returns: 
+        :returns:
 
         """
 
@@ -389,7 +391,7 @@ class Population(object):
         """
         spatial parameters
 
-        :returns: 
+        :returns:
 
         """
 
@@ -487,9 +489,7 @@ class Population(object):
 
         for k, v in self._spatial_params.items():
 
-            spatial_grp.create_dataset(k,
-                                       data=np.array([v]),
-                                       compression="lzf")
+            spatial_grp.create_dataset(k, data=np.array([v]), compression="lzf")
 
         if self._lf_params is not None:
 
@@ -497,9 +497,7 @@ class Population(object):
 
             for k, v in self._lf_params.items():
 
-                lum_grp.create_dataset(k,
-                                       data=np.array([v]),
-                                       compression="lzf")
+                lum_grp.create_dataset(k, data=np.array([v]), compression="lzf")
 
             f.attrs["lf_form"] = np.string_(self._lf_form)
 
@@ -515,16 +513,18 @@ class Population(object):
         f.attrs["r_max"] = self._r_max
         f.attrs["seed"] = int(self._seed)
 
-        f.create_dataset("luminosities",
-                         data=self._luminosities,
-                         compression="lzf")
+        f.create_dataset(
+            "luminosities", data=self._luminosities, compression="lzf"
+        )
         f.create_dataset("distances", data=self._distances, compression="lzf")
-        f.create_dataset("known_distances",
-                         data=self._known_distances,
-                         compression="lzf")
-        f.create_dataset("known_distance_idx",
-                         data=self._known_distance_idx,
-                         compression="lzf")
+        f.create_dataset(
+            "known_distances", data=self._known_distances, compression="lzf"
+        )
+        f.create_dataset(
+            "known_distance_idx",
+            data=self._known_distance_idx,
+            compression="lzf",
+        )
         f.create_dataset(
             "unknown_distance_idx",
             data=self._unknown_distance_idx,
@@ -541,12 +541,12 @@ class Population(object):
         for k, v in self._auxiliary_quantities.items():
 
             q_grp = aux_grp.create_group(k)
-            q_grp.create_dataset("true_values",
-                                 data=v["true_values"],
-                                 compression="lzf")
-            q_grp.create_dataset("obs_values",
-                                 data=v["obs_values"],
-                                 compression="lzf")
+            q_grp.create_dataset(
+                "true_values", data=v["true_values"], compression="lzf"
+            )
+            q_grp.create_dataset(
+                "obs_values", data=v["obs_values"], compression="lzf"
+            )
 
         model_grp = f.create_group("model_spaces")
 
@@ -558,7 +558,8 @@ class Population(object):
         recursively_save_dict_contents_to_group(f, "truth", self._truth)
 
         recursively_save_dict_contents_to_group(
-            f, "graph", fill_graph_dict(nx.to_dict_of_dicts(self._graph)))
+            f, "graph", fill_graph_dict(nx.to_dict_of_dicts(self._graph))
+        )
 
         # now store the popsynth
         recursively_save_dict_contents_to_group(f, "popsynth", self._pop_synth)
@@ -623,7 +624,8 @@ class Population(object):
 
                 lf_params = None
                 lf_form = None
-        except:
+
+        except AttributeError:
 
             lf_params = None
             lf_form = None
@@ -647,7 +649,7 @@ class Population(object):
             known_distance_idx = (f["known_distance_idx"][()]).astype(int)
             unknown_distance_idx = (f["unknown_distance_idx"][()]).astype(int)
 
-        except:
+        except AttributeError:
 
             known_distances = None
             known_distance_idx = None
@@ -676,7 +678,9 @@ class Population(object):
 
         graph = nx.from_dict_of_dicts(
             clean_graph_dict(
-                recursively_load_dict_contents_from_group(f, "graph")))
+                recursively_load_dict_contents_from_group(f, "graph")
+            )
+        )
 
         pop_synth = recursively_load_dict_contents_from_group(f, "popsynth")
 
@@ -856,10 +860,10 @@ class Population(object):
         try:
 
             ax.set_ylim(
-                bottom=min([self._fluxes.min(),
-                            self._flux_selected.min()]))
+                bottom=min([self._fluxes.min(), self._flux_selected.min()])
+            )
 
-        except:
+        except ValueError:
 
             ax.set_ylim(bottom=self._fluxes.min())
 
@@ -909,8 +913,7 @@ class Population(object):
         # ax.set_xscale('log')
         ax.set_yscale("log")
 
-        ax.set_ylim(bottom=min([self._fluxes.min(),
-                                self._flux_selected.min()]))
+        ax.set_ylim(bottom=min([self._fluxes.min(), self._flux_selected.min()]))
         ax.set_xlim(right=self._r_max)
 
         ax.set_xlabel("distance")
@@ -950,9 +953,9 @@ class Population(object):
 
         if (with_arrows) and (not self._no_detection):
             for start, stop, z in zip(
-                    self._fluxes[self._selection],
-                    self._flux_selected,
-                    self._distance_selected,
+                self._fluxes[self._selection],
+                self._flux_selected,
+                self._distance_selected,
             ):
 
                 x = z
@@ -995,14 +998,18 @@ class Population(object):
 
             fig = ax.get_figure()
 
-        ax.scatter(self._distance_selected,
-                   self._luminosity_selected,
-                   s=5,
-                   color=obs_color)
-        ax.scatter(self._distance_hidden,
-                   self._luminosity_hidden,
-                   s=5,
-                   color=true_color)
+        ax.scatter(
+            self._distance_selected,
+            self._luminosity_selected,
+            s=5,
+            color=obs_color,
+        )
+        ax.scatter(
+            self._distance_hidden,
+            self._luminosity_hidden,
+            s=5,
+            color=true_color,
+        )
 
         return fig
 
